@@ -46,7 +46,7 @@ sub show_database_engines {
 
 sub params {
   my ($self, $c) = @_;
-  my $params = {map {$_ => scalar $c->param($_)} $c->param};
+  my $params = $c->req->params->to_hash;
   return $params;
 }
 
